# -*- coding: utf-8 -*-
"""
  moodle-quiz-offline.py
  ~~~~~~~~~~~~~~~~~~~~~~~
  Create moodle questions in xml format,
  from yaml text based database,
  with jinjas templates

  copyright: foro.adre-es.org
  
  This file is part of Moodle-quizs-offline.

  Moodle-quiz-offline is free software: you can redistribute it
  and/or modify it under the terms of the GNU General Public 
  License as published by the Free Software Foundation, either 
  version 3 of the License, or (at your option) any later version.

  Moodle-quiz-offline is distributed in the hope that it will 
  be useful, but WITHOUT ANY WARRANTY; without even the implied 
  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. 
  See the GNU General Public License for more details.

  You should have received a copy of the GNU General Public 
  License along with Moodle-quiz-offline.
  If not, see <http://www.gnu.org/licenses/>.

"""

import jinja2
import codecs
import yaml
import os


# Establece las opciones por defecto
options = {
  'template_path': 'templates',
  'template': 'moodle.xml',
  'feedback': '',
  'shuffle': 0,
  'grade': 1,
  'penalty': 0.5,
  'image': '',
}


def main():
  for f in os.listdir('.'):
    process(f)


def process(fi_name):
  global options

  # Comprueba que el fichero de entrada es de tipo yaml
  if fi_name[-5:].lower() != '.yaml':
    return 
  print 'Process', fi_name
  

  # print yaml.dump([1,2,3, [4, 5, 6], 7])
  # return

  # Lee los datos del fichero yaml   
  text = codecs.open(fi_name, 'r', 'utf-8').read()
  database = []
  for data in yaml.load_all(text):
    database.append(data)


  # Lee las cuestiones
  for data in database:

    # Read external options
    try:
      opt = data[0]['options']
      for item in opt:
        options[item] = opt[item]
      print '  Template =', options['template']
      data = data[1:]
    except:
      pass

    # Load and run template
    templateEnv = jinja2.Environment(loader=jinja2.FileSystemLoader(options['template_path']))
    template = templateEnv.get_template(options['template'])
    outputText = template.render(database=data, opt=options)

    # Elimina el BOM del fichero UTF8
    while (outputText[:1].encode('ascii', 'xmlcharrefreplace') == '&#65279;'):
      outputText = outputText[1:].strip('\n\t ')

    # Write output file
    fout_name = fi_name[:-5] + '.xml'
    fo = codecs.open(fout_name, 'w', 'utf-8-sig')
    fo.write(outputText)
    fo.close()
    print '  Write', fout_name
  

main()
